@@ -98,7 +98,7 @@ mc.wbart <- function(
 
     if(mc.cores==1 | attr(post, 'class')!='wbart') return(post)
     else {
-        if(class(rm.const)!='logical') post$rm.const <- rm.const
+        if(class(rm.const)[1]!='logical') post$rm.const <- rm.const
         post$ndpost <- mc.cores*mc.ndpost
         p <- nrow(x.train[post$rm.const, ])
         ##p <- nrow(x.train[ , post$rm.const])
