@@ -1,6 +1,6 @@
 
 ## BART: Bayesian Additive Regression Trees
-## Copyright (C) 2017 Robert McCulloch and Rodney Sparapani
+## Copyright (C) 2017-2018 Robert McCulloch and Rodney Sparapani
 
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -16,7 +16,8 @@
 ## along with this program; if not, a copy is available at
 ## https://www.R-project.org/Licenses/GPL-2
 
-predict.criskbart <- function(object, newdata, newdata2, mc.cores=1, openmp=(mc.cores.openmp()>0), ...) {
+predict.criskbart <- function(object, newdata, newdata2, mc.cores=1,
+                              openmp=(mc.cores.openmp()>0), ...) {
 
     ## if(class(newdata) != "matrix") stop("newdata must be a matrix")
     ## if(class(newdata2) != "matrix") stop("newdata2 must be a matrix")
@@ -34,9 +35,15 @@ predict.criskbart <- function(object, newdata, newdata2, mc.cores=1, openmp=(mc.
     if(.Platform$OS.type == "unix") mc.cores.detected <- detectCores()
     else mc.cores.detected <- NA
 
-    if(!is.na(mc.cores.detected) && mc.cores>mc.cores.detected) mc.cores <- mc.cores.detected
+    if(!is.na(mc.cores.detected) && mc.cores>mc.cores.detected)
+        mc.cores <- mc.cores.detected
 
-    return(mc.crisk.pwbart(newdata, newdata2, object$treedraws, object$treedraws2,
-                           object$binaryOffset, object$binaryOffset2, mc.cores=mc.cores, ...))
+    if(length(object$binaryOffset)==0) object$binaryOffset=object$offset
+    if(length(object$binaryOffset2)==0) object$binaryOffset2=object$offset2
+
+    return(mc.crisk.pwbart(newdata, newdata2,
+                           object$treedraws, object$treedraws2,
+                           object$binaryOffset, object$binaryOffset2,
+                           mc.cores=mc.cores, type=object$type, ...))
 }
 
